# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rockset import document_locator_pb2 as rockset_dot_document__locator__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rockset/value.proto',
  package='rockset',
  syntax='proto3',
  serialized_options=b'\n\020io.rockset.protoP\000\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13rockset/value.proto\x12\x07rockset\x1a\x1erockset/document_locator.proto\"\x07\n\x05\x45mpty\"5\n\tDateProto\x12\x0c\n\x04year\x18\x01 \x01(\x03\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"N\n\tTimeProto\x12\x0c\n\x04hour\x18\x01 \x01(\x05\x12\x0e\n\x06minute\x18\x02 \x01(\x05\x12\x0e\n\x06second\x18\x03 \x01(\x05\x12\x13\n\x0bmicrosecond\x18\x04 \x01(\x05\"S\n\rDateTimeProto\x12 \n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x12.rockset.DateProto\x12 \n\x04time\x18\x02 \x01(\x0b\x32\x12.rockset.TimeProto\":\n\x13GeographyPointProto\x12\x11\n\tlongitude\x18\x01 \x01(\x01\x12\x10\n\x08latitude\x18\x02 \x01(\x01\"H\n\x18GeographyLineStringProto\x12,\n\x06points\x18\x01 \x03(\x0b\x32\x1c.rockset.GeographyPointProto\"I\n\x15GeographyPolygonProto\x12\x30\n\x05loops\x18\x01 \x03(\x0b\x32!.rockset.GeographyLineStringProto\"1\n\x1bGeographyRangeEndpointProto\x12\x12\n\nindex_term\x18\x01 \x01(\t\"\xff\x01\n\x0eGeographyProto\x12-\n\x05point\x18\x01 \x01(\x0b\x32\x1c.rockset.GeographyPointProtoH\x00\x12\x38\n\x0bline_string\x18\x02 \x01(\x0b\x32!.rockset.GeographyLineStringProtoH\x00\x12\x31\n\x07polygon\x18\x03 \x01(\x0b\x32\x1e.rockset.GeographyPolygonProtoH\x00\x12>\n\x0erange_endpoint\x18\x04 \x01(\x0b\x32$.rockset.GeographyRangeEndpointProtoH\x00\x42\x11\n\x0fgeography_union\"%\n\x0bInt128Proto\x12\n\n\x02hi\x18\x01 \x01(\x04\x12\n\n\x02lo\x18\x02 \x01(\x04\"\x86\x0b\n\x05Value\x12\x13\n\tint_value\x18\x01 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x02 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x03 \x01(\x08H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x05 \x01(\x0cH\x00\x12,\n\x0cobject_value\x18\x06 \x01(\x0b\x32\x14.rockset.ObjectValueH\x00\x12*\n\x0b\x61rray_value\x18\x07 \x01(\x0b\x32\x13.rockset.ArrayValueH\x00\x12,\n\x0c\x63ustom_value\x18\x08 \x01(\x0b\x32\x14.rockset.CustomValueH\x00\x12\x14\n\nnull_value\x18\t \x01(\x08H\x00\x12.\n\rlocator_value\x18\n \x01(\x0b\x32\x15.DocumentLocatorProtoH\x00\x12\x19\n\x0ftimestamp_value\x18\x0b \x01(\x03H\x00\x12\x30\n\x0e\x64\x61tetime_value\x18\x0c \x01(\x0b\x32\x16.rockset.DateTimeProtoH\x00\x12(\n\ndate_value\x18\r \x01(\x0b\x32\x12.rockset.DateProtoH\x00\x12(\n\ntime_value\x18\x0e \x01(\x0b\x32\x12.rockset.TimeProtoH\x00\x12\x1e\n\x14month_interval_value\x18\x0f \x01(\x03H\x00\x12$\n\x1amicrosecond_interval_value\x18\x10 \x01(\x03H\x00\x12\x17\n\runknown_value\x18\x11 \x01(\x08H\x00\x12\x32\n\x0fgeography_value\x18\x12 \x01(\x0b\x32\x17.rockset.GeographyProtoH\x00\x12\x31\n\x0fint_array_value\x18\x13 \x01(\x0b\x32\x16.rockset.IntArrayValueH\x00\x12\x35\n\x11\x66loat_array_value\x18\x14 \x01(\x0b\x32\x18.rockset.FloatArrayValueH\x00\x12\x33\n\x10\x62ool_array_value\x18\x15 \x01(\x0b\x32\x17.rockset.BoolArrayValueH\x00\x12\x37\n\x12string_array_value\x18\x16 \x01(\x0b\x32\x19.rockset.StringArrayValueH\x00\x12\x39\n\x13locator_array_value\x18\x17 \x01(\x0b\x32\x1a.rockset.LocatorArrayValueH\x00\x12=\n\x15timestamp_array_value\x18\x18 \x01(\x0b\x32\x1c.rockset.TimestampArrayValueH\x00\x12<\n\x15\x64\x61te_time_array_value\x18\x19 \x01(\x0b\x32\x1b.rockset.DateTimeArrayValueH\x00\x12\x33\n\x10\x64\x61te_array_value\x18\x1a \x01(\x0b\x32\x17.rockset.DateArrayValueH\x00\x12\x33\n\x10time_array_value\x18\x1b \x01(\x0b\x32\x17.rockset.TimeArrayValueH\x00\x12\x46\n\x1amonth_interval_array_value\x18\x1c \x01(\x0b\x32 .rockset.MonthIntervalArrayValueH\x00\x12R\n microsecond_interval_array_value\x18\x1d \x01(\x0b\x32&.rockset.MicrosecondIntervalArrayValueH\x00\x12,\n\x0cint128_value\x18\x1e \x01(\x0b\x32\x14.rockset.Int128ProtoH\x00\x12\x37\n\x12int128_array_value\x18\x1f \x01(\x0b\x32\x19.rockset.Int128ArrayValueH\x00\x42\r\n\x0bvalue_union\",\n\x0b\x43ustomValue\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0f\n\x07\x65ncoded\x18\x02 \x01(\x0c\"3\n\x05\x46ield\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.rockset.Value\"-\n\x0bObjectValue\x12\x1e\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x0e.rockset.Field\"+\n\nArrayValue\x12\x1d\n\x05value\x18\x02 \x03(\x0b\x32\x0e.rockset.Value\"\x1d\n\nNullsValue\x12\x0f\n\x07storage\x18\x01 \x03(\x04\"B\n\rIntArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"D\n\x0f\x46loatArrayValue\x12\r\n\x05value\x18\x01 \x03(\x01\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"C\n\x0e\x42oolArrayValue\x12\r\n\x05value\x18\x01 \x03(\x08\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"<\n\x1aStringArrayValueDictionary\x12\x0f\n\x07offsets\x18\x01 \x03(\r\x12\r\n\x05words\x18\x02 \x01(\x0c\"~\n\x10StringArrayValue\x12\r\n\x05value\x18\x01 \x03(\r\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\x12\x37\n\ndictionary\x18\x03 \x01(\x0b\x32#.rockset.StringArrayValueDictionary\"]\n\x11LocatorArrayValue\x12$\n\x05value\x18\x01 \x03(\x0b\x32\x15.DocumentLocatorProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"H\n\x13TimestampArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"_\n\x12\x44\x61teTimeArrayValue\x12%\n\x05value\x18\x01 \x03(\x0b\x32\x16.rockset.DateTimeProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"W\n\x0e\x44\x61teArrayValue\x12!\n\x05value\x18\x01 \x03(\x0b\x32\x12.rockset.DateProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"W\n\x0eTimeArrayValue\x12!\n\x05value\x18\x01 \x03(\x0b\x32\x12.rockset.TimeProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"L\n\x17MonthIntervalArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"R\n\x1dMicrosecondIntervalArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"[\n\x10Int128ArrayValue\x12#\n\x05value\x18\x01 \x03(\x0b\x32\x14.rockset.Int128Proto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"\x8c\x03\n\x04Type\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x18.rockset.Type.ScalarTypeH\x00\x12*\n\x0bobject_type\x18\x02 \x01(\x0b\x32\x13.rockset.ObjectTypeH\x00\x12(\n\narray_type\x18\x03 \x01(\x0b\x32\x12.rockset.ArrayTypeH\x00\x12*\n\x0b\x63ustom_type\x18\x04 \x01(\x0b\x32\x13.rockset.CustomTypeH\x00\x12\x10\n\x08inferred\x18\x05 \x01(\x08\x12%\n\rdefault_value\x18\x06 \x01(\x0b\x32\x0e.rockset.Value\x12#\n\x0csource_field\x18\x07 \x01(\x0b\x32\r.rockset.Type\x12\x0e\n\x06stored\x18\x08 \x01(\x08\x12\x0f\n\x07indexed\x18\t \x01(\x08\"K\n\nScalarType\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03INT\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\x08\n\x04\x42OOL\x10\x03\x12\n\n\x06STRING\x10\x04\x12\t\n\x05\x42YTES\x10\x05\x42\x0c\n\ntype_union\"3\n\x07KeyType\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x04type\x18\x02 \x01(\x0b\x32\r.rockset.Type\"*\n\nObjectType\x12\x1c\n\x02kt\x18\x01 \x03(\x0b\x32\x10.rockset.KeyType\"(\n\tArrayType\x12\x1b\n\x04type\x18\x01 \x01(\x0b\x32\r.rockset.Type\"\x1a\n\nCustomType\x12\x0c\n\x04type\x18\x01 \x01(\r\"\x1d\n\x0b\x42itSetProto\x12\x0e\n\x06\x62locks\x18\x01 \x03(\x07\x42\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[rockset_dot_document__locator__pb2.DESCRIPTOR,])



_TYPE_SCALARTYPE = _descriptor.EnumDescriptor(
  name='ScalarType',
  full_name='rockset.Type.ScalarType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BYTES', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3893,
  serialized_end=3968,
)
_sym_db.RegisterEnumDescriptor(_TYPE_SCALARTYPE)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='rockset.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=71,
)


_DATEPROTO = _descriptor.Descriptor(
  name='DateProto',
  full_name='rockset.DateProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='rockset.DateProto.year', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='rockset.DateProto.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='rockset.DateProto.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=126,
)


_TIMEPROTO = _descriptor.Descriptor(
  name='TimeProto',
  full_name='rockset.TimeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hour', full_name='rockset.TimeProto.hour', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute', full_name='rockset.TimeProto.minute', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second', full_name='rockset.TimeProto.second', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microsecond', full_name='rockset.TimeProto.microsecond', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=206,
)


_DATETIMEPROTO = _descriptor.Descriptor(
  name='DateTimeProto',
  full_name='rockset.DateTimeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='rockset.DateTimeProto.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='rockset.DateTimeProto.time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=291,
)


_GEOGRAPHYPOINTPROTO = _descriptor.Descriptor(
  name='GeographyPointProto',
  full_name='rockset.GeographyPointProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='longitude', full_name='rockset.GeographyPointProto.longitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='rockset.GeographyPointProto.latitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=351,
)


_GEOGRAPHYLINESTRINGPROTO = _descriptor.Descriptor(
  name='GeographyLineStringProto',
  full_name='rockset.GeographyLineStringProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='rockset.GeographyLineStringProto.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=425,
)


_GEOGRAPHYPOLYGONPROTO = _descriptor.Descriptor(
  name='GeographyPolygonProto',
  full_name='rockset.GeographyPolygonProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loops', full_name='rockset.GeographyPolygonProto.loops', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=500,
)


_GEOGRAPHYRANGEENDPOINTPROTO = _descriptor.Descriptor(
  name='GeographyRangeEndpointProto',
  full_name='rockset.GeographyRangeEndpointProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index_term', full_name='rockset.GeographyRangeEndpointProto.index_term', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=551,
)


_GEOGRAPHYPROTO = _descriptor.Descriptor(
  name='GeographyProto',
  full_name='rockset.GeographyProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='rockset.GeographyProto.point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_string', full_name='rockset.GeographyProto.line_string', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='rockset.GeographyProto.polygon', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_endpoint', full_name='rockset.GeographyProto.range_endpoint', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='geography_union', full_name='rockset.GeographyProto.geography_union',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=554,
  serialized_end=809,
)


_INT128PROTO = _descriptor.Descriptor(
  name='Int128Proto',
  full_name='rockset.Int128Proto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hi', full_name='rockset.Int128Proto.hi', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lo', full_name='rockset.Int128Proto.lo', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=848,
)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='rockset.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='int_value', full_name='rockset.Value.int_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='rockset.Value.float_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='rockset.Value.bool_value', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='rockset.Value.string_value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='rockset.Value.bytes_value', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_value', full_name='rockset.Value.object_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_value', full_name='rockset.Value.array_value', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_value', full_name='rockset.Value.custom_value', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_value', full_name='rockset.Value.null_value', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator_value', full_name='rockset.Value.locator_value', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_value', full_name='rockset.Value.timestamp_value', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datetime_value', full_name='rockset.Value.datetime_value', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_value', full_name='rockset.Value.date_value', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_value', full_name='rockset.Value.time_value', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month_interval_value', full_name='rockset.Value.month_interval_value', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microsecond_interval_value', full_name='rockset.Value.microsecond_interval_value', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unknown_value', full_name='rockset.Value.unknown_value', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geography_value', full_name='rockset.Value.geography_value', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_array_value', full_name='rockset.Value.int_array_value', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_array_value', full_name='rockset.Value.float_array_value', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_array_value', full_name='rockset.Value.bool_array_value', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_array_value', full_name='rockset.Value.string_array_value', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator_array_value', full_name='rockset.Value.locator_array_value', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_array_value', full_name='rockset.Value.timestamp_array_value', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_time_array_value', full_name='rockset.Value.date_time_array_value', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_array_value', full_name='rockset.Value.date_array_value', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_array_value', full_name='rockset.Value.time_array_value', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month_interval_array_value', full_name='rockset.Value.month_interval_array_value', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microsecond_interval_array_value', full_name='rockset.Value.microsecond_interval_array_value', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int128_value', full_name='rockset.Value.int128_value', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int128_array_value', full_name='rockset.Value.int128_array_value', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value_union', full_name='rockset.Value.value_union',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=851,
  serialized_end=2265,
)


_CUSTOMVALUE = _descriptor.Descriptor(
  name='CustomValue',
  full_name='rockset.CustomValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.CustomValue.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoded', full_name='rockset.CustomValue.encoded', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2267,
  serialized_end=2311,
)


_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='rockset.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rockset.Field.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.Field.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2313,
  serialized_end=2364,
)


_OBJECTVALUE = _descriptor.Descriptor(
  name='ObjectValue',
  full_name='rockset.ObjectValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='rockset.ObjectValue.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2366,
  serialized_end=2411,
)


_ARRAYVALUE = _descriptor.Descriptor(
  name='ArrayValue',
  full_name='rockset.ArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.ArrayValue.value', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2413,
  serialized_end=2456,
)


_NULLSVALUE = _descriptor.Descriptor(
  name='NullsValue',
  full_name='rockset.NullsValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='rockset.NullsValue.storage', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2458,
  serialized_end=2487,
)


_INTARRAYVALUE = _descriptor.Descriptor(
  name='IntArrayValue',
  full_name='rockset.IntArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.IntArrayValue.value', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.IntArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2489,
  serialized_end=2555,
)


_FLOATARRAYVALUE = _descriptor.Descriptor(
  name='FloatArrayValue',
  full_name='rockset.FloatArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.FloatArrayValue.value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.FloatArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2557,
  serialized_end=2625,
)


_BOOLARRAYVALUE = _descriptor.Descriptor(
  name='BoolArrayValue',
  full_name='rockset.BoolArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.BoolArrayValue.value', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.BoolArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2627,
  serialized_end=2694,
)


_STRINGARRAYVALUEDICTIONARY = _descriptor.Descriptor(
  name='StringArrayValueDictionary',
  full_name='rockset.StringArrayValueDictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offsets', full_name='rockset.StringArrayValueDictionary.offsets', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='words', full_name='rockset.StringArrayValueDictionary.words', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2696,
  serialized_end=2756,
)


_STRINGARRAYVALUE = _descriptor.Descriptor(
  name='StringArrayValue',
  full_name='rockset.StringArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.StringArrayValue.value', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.StringArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dictionary', full_name='rockset.StringArrayValue.dictionary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2758,
  serialized_end=2884,
)


_LOCATORARRAYVALUE = _descriptor.Descriptor(
  name='LocatorArrayValue',
  full_name='rockset.LocatorArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.LocatorArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.LocatorArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2886,
  serialized_end=2979,
)


_TIMESTAMPARRAYVALUE = _descriptor.Descriptor(
  name='TimestampArrayValue',
  full_name='rockset.TimestampArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.TimestampArrayValue.value', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.TimestampArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2981,
  serialized_end=3053,
)


_DATETIMEARRAYVALUE = _descriptor.Descriptor(
  name='DateTimeArrayValue',
  full_name='rockset.DateTimeArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.DateTimeArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.DateTimeArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3055,
  serialized_end=3150,
)


_DATEARRAYVALUE = _descriptor.Descriptor(
  name='DateArrayValue',
  full_name='rockset.DateArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.DateArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.DateArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3152,
  serialized_end=3239,
)


_TIMEARRAYVALUE = _descriptor.Descriptor(
  name='TimeArrayValue',
  full_name='rockset.TimeArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.TimeArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.TimeArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3241,
  serialized_end=3328,
)


_MONTHINTERVALARRAYVALUE = _descriptor.Descriptor(
  name='MonthIntervalArrayValue',
  full_name='rockset.MonthIntervalArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.MonthIntervalArrayValue.value', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.MonthIntervalArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3330,
  serialized_end=3406,
)


_MICROSECONDINTERVALARRAYVALUE = _descriptor.Descriptor(
  name='MicrosecondIntervalArrayValue',
  full_name='rockset.MicrosecondIntervalArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.MicrosecondIntervalArrayValue.value', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.MicrosecondIntervalArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3408,
  serialized_end=3490,
)


_INT128ARRAYVALUE = _descriptor.Descriptor(
  name='Int128ArrayValue',
  full_name='rockset.Int128ArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.Int128ArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.Int128ArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3492,
  serialized_end=3583,
)


_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='rockset.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.Type.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_type', full_name='rockset.Type.object_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_type', full_name='rockset.Type.array_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_type', full_name='rockset.Type.custom_type', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inferred', full_name='rockset.Type.inferred', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='rockset.Type.default_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_field', full_name='rockset.Type.source_field', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored', full_name='rockset.Type.stored', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indexed', full_name='rockset.Type.indexed', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TYPE_SCALARTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type_union', full_name='rockset.Type.type_union',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3586,
  serialized_end=3982,
)


_KEYTYPE = _descriptor.Descriptor(
  name='KeyType',
  full_name='rockset.KeyType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rockset.KeyType.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.KeyType.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3984,
  serialized_end=4035,
)


_OBJECTTYPE = _descriptor.Descriptor(
  name='ObjectType',
  full_name='rockset.ObjectType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kt', full_name='rockset.ObjectType.kt', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4037,
  serialized_end=4079,
)


_ARRAYTYPE = _descriptor.Descriptor(
  name='ArrayType',
  full_name='rockset.ArrayType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.ArrayType.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4081,
  serialized_end=4121,
)


_CUSTOMTYPE = _descriptor.Descriptor(
  name='CustomType',
  full_name='rockset.CustomType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.CustomType.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4123,
  serialized_end=4149,
)


_BITSETPROTO = _descriptor.Descriptor(
  name='BitSetProto',
  full_name='rockset.BitSetProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='rockset.BitSetProto.blocks', index=0,
      number=1, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4151,
  serialized_end=4180,
)

_DATETIMEPROTO.fields_by_name['date'].message_type = _DATEPROTO
_DATETIMEPROTO.fields_by_name['time'].message_type = _TIMEPROTO
_GEOGRAPHYLINESTRINGPROTO.fields_by_name['points'].message_type = _GEOGRAPHYPOINTPROTO
_GEOGRAPHYPOLYGONPROTO.fields_by_name['loops'].message_type = _GEOGRAPHYLINESTRINGPROTO
_GEOGRAPHYPROTO.fields_by_name['point'].message_type = _GEOGRAPHYPOINTPROTO
_GEOGRAPHYPROTO.fields_by_name['line_string'].message_type = _GEOGRAPHYLINESTRINGPROTO
_GEOGRAPHYPROTO.fields_by_name['polygon'].message_type = _GEOGRAPHYPOLYGONPROTO
_GEOGRAPHYPROTO.fields_by_name['range_endpoint'].message_type = _GEOGRAPHYRANGEENDPOINTPROTO
_GEOGRAPHYPROTO.oneofs_by_name['geography_union'].fields.append(
  _GEOGRAPHYPROTO.fields_by_name['point'])
_GEOGRAPHYPROTO.fields_by_name['point'].containing_oneof = _GEOGRAPHYPROTO.oneofs_by_name['geography_union']
_GEOGRAPHYPROTO.oneofs_by_name['geography_union'].fields.append(
  _GEOGRAPHYPROTO.fields_by_name['line_string'])
_GEOGRAPHYPROTO.fields_by_name['line_string'].containing_oneof = _GEOGRAPHYPROTO.oneofs_by_name['geography_union']
_GEOGRAPHYPROTO.oneofs_by_name['geography_union'].fields.append(
  _GEOGRAPHYPROTO.fields_by_name['polygon'])
_GEOGRAPHYPROTO.fields_by_name['polygon'].containing_oneof = _GEOGRAPHYPROTO.oneofs_by_name['geography_union']
_GEOGRAPHYPROTO.oneofs_by_name['geography_union'].fields.append(
  _GEOGRAPHYPROTO.fields_by_name['range_endpoint'])
_GEOGRAPHYPROTO.fields_by_name['range_endpoint'].containing_oneof = _GEOGRAPHYPROTO.oneofs_by_name['geography_union']
_VALUE.fields_by_name['object_value'].message_type = _OBJECTVALUE
_VALUE.fields_by_name['array_value'].message_type = _ARRAYVALUE
_VALUE.fields_by_name['custom_value'].message_type = _CUSTOMVALUE
_VALUE.fields_by_name['locator_value'].message_type = rockset_dot_document__locator__pb2._DOCUMENTLOCATORPROTO
_VALUE.fields_by_name['datetime_value'].message_type = _DATETIMEPROTO
_VALUE.fields_by_name['date_value'].message_type = _DATEPROTO
_VALUE.fields_by_name['time_value'].message_type = _TIMEPROTO
_VALUE.fields_by_name['geography_value'].message_type = _GEOGRAPHYPROTO
_VALUE.fields_by_name['int_array_value'].message_type = _INTARRAYVALUE
_VALUE.fields_by_name['float_array_value'].message_type = _FLOATARRAYVALUE
_VALUE.fields_by_name['bool_array_value'].message_type = _BOOLARRAYVALUE
_VALUE.fields_by_name['string_array_value'].message_type = _STRINGARRAYVALUE
_VALUE.fields_by_name['locator_array_value'].message_type = _LOCATORARRAYVALUE
_VALUE.fields_by_name['timestamp_array_value'].message_type = _TIMESTAMPARRAYVALUE
_VALUE.fields_by_name['date_time_array_value'].message_type = _DATETIMEARRAYVALUE
_VALUE.fields_by_name['date_array_value'].message_type = _DATEARRAYVALUE
_VALUE.fields_by_name['time_array_value'].message_type = _TIMEARRAYVALUE
_VALUE.fields_by_name['month_interval_array_value'].message_type = _MONTHINTERVALARRAYVALUE
_VALUE.fields_by_name['microsecond_interval_array_value'].message_type = _MICROSECONDINTERVALARRAYVALUE
_VALUE.fields_by_name['int128_value'].message_type = _INT128PROTO
_VALUE.fields_by_name['int128_array_value'].message_type = _INT128ARRAYVALUE
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['int_value'])
_VALUE.fields_by_name['int_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['float_value'])
_VALUE.fields_by_name['float_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['bool_value'])
_VALUE.fields_by_name['bool_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['string_value'])
_VALUE.fields_by_name['string_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['bytes_value'])
_VALUE.fields_by_name['bytes_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['object_value'])
_VALUE.fields_by_name['object_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['array_value'])
_VALUE.fields_by_name['array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['custom_value'])
_VALUE.fields_by_name['custom_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['null_value'])
_VALUE.fields_by_name['null_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['locator_value'])
_VALUE.fields_by_name['locator_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['timestamp_value'])
_VALUE.fields_by_name['timestamp_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['datetime_value'])
_VALUE.fields_by_name['datetime_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['date_value'])
_VALUE.fields_by_name['date_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['time_value'])
_VALUE.fields_by_name['time_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['month_interval_value'])
_VALUE.fields_by_name['month_interval_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['microsecond_interval_value'])
_VALUE.fields_by_name['microsecond_interval_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['unknown_value'])
_VALUE.fields_by_name['unknown_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['geography_value'])
_VALUE.fields_by_name['geography_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['int_array_value'])
_VALUE.fields_by_name['int_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['float_array_value'])
_VALUE.fields_by_name['float_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['bool_array_value'])
_VALUE.fields_by_name['bool_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['string_array_value'])
_VALUE.fields_by_name['string_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['locator_array_value'])
_VALUE.fields_by_name['locator_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['timestamp_array_value'])
_VALUE.fields_by_name['timestamp_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['date_time_array_value'])
_VALUE.fields_by_name['date_time_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['date_array_value'])
_VALUE.fields_by_name['date_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['time_array_value'])
_VALUE.fields_by_name['time_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['month_interval_array_value'])
_VALUE.fields_by_name['month_interval_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['microsecond_interval_array_value'])
_VALUE.fields_by_name['microsecond_interval_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['int128_value'])
_VALUE.fields_by_name['int128_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['int128_array_value'])
_VALUE.fields_by_name['int128_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_FIELD.fields_by_name['value'].message_type = _VALUE
_OBJECTVALUE.fields_by_name['fields'].message_type = _FIELD
_ARRAYVALUE.fields_by_name['value'].message_type = _VALUE
_INTARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_FLOATARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_BOOLARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_STRINGARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_STRINGARRAYVALUE.fields_by_name['dictionary'].message_type = _STRINGARRAYVALUEDICTIONARY
_LOCATORARRAYVALUE.fields_by_name['value'].message_type = rockset_dot_document__locator__pb2._DOCUMENTLOCATORPROTO
_LOCATORARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_TIMESTAMPARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_DATETIMEARRAYVALUE.fields_by_name['value'].message_type = _DATETIMEPROTO
_DATETIMEARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_DATEARRAYVALUE.fields_by_name['value'].message_type = _DATEPROTO
_DATEARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_TIMEARRAYVALUE.fields_by_name['value'].message_type = _TIMEPROTO
_TIMEARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_MONTHINTERVALARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_MICROSECONDINTERVALARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_INT128ARRAYVALUE.fields_by_name['value'].message_type = _INT128PROTO
_INT128ARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_TYPE.fields_by_name['type'].enum_type = _TYPE_SCALARTYPE
_TYPE.fields_by_name['object_type'].message_type = _OBJECTTYPE
_TYPE.fields_by_name['array_type'].message_type = _ARRAYTYPE
_TYPE.fields_by_name['custom_type'].message_type = _CUSTOMTYPE
_TYPE.fields_by_name['default_value'].message_type = _VALUE
_TYPE.fields_by_name['source_field'].message_type = _TYPE
_TYPE_SCALARTYPE.containing_type = _TYPE
_TYPE.oneofs_by_name['type_union'].fields.append(
  _TYPE.fields_by_name['type'])
_TYPE.fields_by_name['type'].containing_oneof = _TYPE.oneofs_by_name['type_union']
_TYPE.oneofs_by_name['type_union'].fields.append(
  _TYPE.fields_by_name['object_type'])
_TYPE.fields_by_name['object_type'].containing_oneof = _TYPE.oneofs_by_name['type_union']
_TYPE.oneofs_by_name['type_union'].fields.append(
  _TYPE.fields_by_name['array_type'])
_TYPE.fields_by_name['array_type'].containing_oneof = _TYPE.oneofs_by_name['type_union']
_TYPE.oneofs_by_name['type_union'].fields.append(
  _TYPE.fields_by_name['custom_type'])
_TYPE.fields_by_name['custom_type'].containing_oneof = _TYPE.oneofs_by_name['type_union']
_KEYTYPE.fields_by_name['type'].message_type = _TYPE
_OBJECTTYPE.fields_by_name['kt'].message_type = _KEYTYPE
_ARRAYTYPE.fields_by_name['type'].message_type = _TYPE
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['DateProto'] = _DATEPROTO
DESCRIPTOR.message_types_by_name['TimeProto'] = _TIMEPROTO
DESCRIPTOR.message_types_by_name['DateTimeProto'] = _DATETIMEPROTO
DESCRIPTOR.message_types_by_name['GeographyPointProto'] = _GEOGRAPHYPOINTPROTO
DESCRIPTOR.message_types_by_name['GeographyLineStringProto'] = _GEOGRAPHYLINESTRINGPROTO
DESCRIPTOR.message_types_by_name['GeographyPolygonProto'] = _GEOGRAPHYPOLYGONPROTO
DESCRIPTOR.message_types_by_name['GeographyRangeEndpointProto'] = _GEOGRAPHYRANGEENDPOINTPROTO
DESCRIPTOR.message_types_by_name['GeographyProto'] = _GEOGRAPHYPROTO
DESCRIPTOR.message_types_by_name['Int128Proto'] = _INT128PROTO
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['CustomValue'] = _CUSTOMVALUE
DESCRIPTOR.message_types_by_name['Field'] = _FIELD
DESCRIPTOR.message_types_by_name['ObjectValue'] = _OBJECTVALUE
DESCRIPTOR.message_types_by_name['ArrayValue'] = _ARRAYVALUE
DESCRIPTOR.message_types_by_name['NullsValue'] = _NULLSVALUE
DESCRIPTOR.message_types_by_name['IntArrayValue'] = _INTARRAYVALUE
DESCRIPTOR.message_types_by_name['FloatArrayValue'] = _FLOATARRAYVALUE
DESCRIPTOR.message_types_by_name['BoolArrayValue'] = _BOOLARRAYVALUE
DESCRIPTOR.message_types_by_name['StringArrayValueDictionary'] = _STRINGARRAYVALUEDICTIONARY
DESCRIPTOR.message_types_by_name['StringArrayValue'] = _STRINGARRAYVALUE
DESCRIPTOR.message_types_by_name['LocatorArrayValue'] = _LOCATORARRAYVALUE
DESCRIPTOR.message_types_by_name['TimestampArrayValue'] = _TIMESTAMPARRAYVALUE
DESCRIPTOR.message_types_by_name['DateTimeArrayValue'] = _DATETIMEARRAYVALUE
DESCRIPTOR.message_types_by_name['DateArrayValue'] = _DATEARRAYVALUE
DESCRIPTOR.message_types_by_name['TimeArrayValue'] = _TIMEARRAYVALUE
DESCRIPTOR.message_types_by_name['MonthIntervalArrayValue'] = _MONTHINTERVALARRAYVALUE
DESCRIPTOR.message_types_by_name['MicrosecondIntervalArrayValue'] = _MICROSECONDINTERVALARRAYVALUE
DESCRIPTOR.message_types_by_name['Int128ArrayValue'] = _INT128ARRAYVALUE
DESCRIPTOR.message_types_by_name['Type'] = _TYPE
DESCRIPTOR.message_types_by_name['KeyType'] = _KEYTYPE
DESCRIPTOR.message_types_by_name['ObjectType'] = _OBJECTTYPE
DESCRIPTOR.message_types_by_name['ArrayType'] = _ARRAYTYPE
DESCRIPTOR.message_types_by_name['CustomType'] = _CUSTOMTYPE
DESCRIPTOR.message_types_by_name['BitSetProto'] = _BITSETPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Empty)
  })
_sym_db.RegisterMessage(Empty)

DateProto = _reflection.GeneratedProtocolMessageType('DateProto', (_message.Message,), {
  'DESCRIPTOR' : _DATEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateProto)
  })
_sym_db.RegisterMessage(DateProto)

TimeProto = _reflection.GeneratedProtocolMessageType('TimeProto', (_message.Message,), {
  'DESCRIPTOR' : _TIMEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimeProto)
  })
_sym_db.RegisterMessage(TimeProto)

DateTimeProto = _reflection.GeneratedProtocolMessageType('DateTimeProto', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateTimeProto)
  })
_sym_db.RegisterMessage(DateTimeProto)

GeographyPointProto = _reflection.GeneratedProtocolMessageType('GeographyPointProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPOINTPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyPointProto)
  })
_sym_db.RegisterMessage(GeographyPointProto)

GeographyLineStringProto = _reflection.GeneratedProtocolMessageType('GeographyLineStringProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYLINESTRINGPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyLineStringProto)
  })
_sym_db.RegisterMessage(GeographyLineStringProto)

GeographyPolygonProto = _reflection.GeneratedProtocolMessageType('GeographyPolygonProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPOLYGONPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyPolygonProto)
  })
_sym_db.RegisterMessage(GeographyPolygonProto)

GeographyRangeEndpointProto = _reflection.GeneratedProtocolMessageType('GeographyRangeEndpointProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYRANGEENDPOINTPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyRangeEndpointProto)
  })
_sym_db.RegisterMessage(GeographyRangeEndpointProto)

GeographyProto = _reflection.GeneratedProtocolMessageType('GeographyProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyProto)
  })
_sym_db.RegisterMessage(GeographyProto)

Int128Proto = _reflection.GeneratedProtocolMessageType('Int128Proto', (_message.Message,), {
  'DESCRIPTOR' : _INT128PROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Int128Proto)
  })
_sym_db.RegisterMessage(Int128Proto)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Value)
  })
_sym_db.RegisterMessage(Value)

CustomValue = _reflection.GeneratedProtocolMessageType('CustomValue', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.CustomValue)
  })
_sym_db.RegisterMessage(CustomValue)

Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
  'DESCRIPTOR' : _FIELD,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Field)
  })
_sym_db.RegisterMessage(Field)

ObjectValue = _reflection.GeneratedProtocolMessageType('ObjectValue', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ObjectValue)
  })
_sym_db.RegisterMessage(ObjectValue)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ArrayValue)
  })
_sym_db.RegisterMessage(ArrayValue)

NullsValue = _reflection.GeneratedProtocolMessageType('NullsValue', (_message.Message,), {
  'DESCRIPTOR' : _NULLSVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.NullsValue)
  })
_sym_db.RegisterMessage(NullsValue)

IntArrayValue = _reflection.GeneratedProtocolMessageType('IntArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _INTARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.IntArrayValue)
  })
_sym_db.RegisterMessage(IntArrayValue)

FloatArrayValue = _reflection.GeneratedProtocolMessageType('FloatArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _FLOATARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.FloatArrayValue)
  })
_sym_db.RegisterMessage(FloatArrayValue)

BoolArrayValue = _reflection.GeneratedProtocolMessageType('BoolArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _BOOLARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.BoolArrayValue)
  })
_sym_db.RegisterMessage(BoolArrayValue)

StringArrayValueDictionary = _reflection.GeneratedProtocolMessageType('StringArrayValueDictionary', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAYVALUEDICTIONARY,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.StringArrayValueDictionary)
  })
_sym_db.RegisterMessage(StringArrayValueDictionary)

StringArrayValue = _reflection.GeneratedProtocolMessageType('StringArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.StringArrayValue)
  })
_sym_db.RegisterMessage(StringArrayValue)

LocatorArrayValue = _reflection.GeneratedProtocolMessageType('LocatorArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _LOCATORARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.LocatorArrayValue)
  })
_sym_db.RegisterMessage(LocatorArrayValue)

TimestampArrayValue = _reflection.GeneratedProtocolMessageType('TimestampArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimestampArrayValue)
  })
_sym_db.RegisterMessage(TimestampArrayValue)

DateTimeArrayValue = _reflection.GeneratedProtocolMessageType('DateTimeArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateTimeArrayValue)
  })
_sym_db.RegisterMessage(DateTimeArrayValue)

DateArrayValue = _reflection.GeneratedProtocolMessageType('DateArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _DATEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateArrayValue)
  })
_sym_db.RegisterMessage(DateArrayValue)

TimeArrayValue = _reflection.GeneratedProtocolMessageType('TimeArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimeArrayValue)
  })
_sym_db.RegisterMessage(TimeArrayValue)

MonthIntervalArrayValue = _reflection.GeneratedProtocolMessageType('MonthIntervalArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _MONTHINTERVALARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.MonthIntervalArrayValue)
  })
_sym_db.RegisterMessage(MonthIntervalArrayValue)

MicrosecondIntervalArrayValue = _reflection.GeneratedProtocolMessageType('MicrosecondIntervalArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _MICROSECONDINTERVALARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.MicrosecondIntervalArrayValue)
  })
_sym_db.RegisterMessage(MicrosecondIntervalArrayValue)

Int128ArrayValue = _reflection.GeneratedProtocolMessageType('Int128ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _INT128ARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Int128ArrayValue)
  })
_sym_db.RegisterMessage(Int128ArrayValue)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
  'DESCRIPTOR' : _TYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Type)
  })
_sym_db.RegisterMessage(Type)

KeyType = _reflection.GeneratedProtocolMessageType('KeyType', (_message.Message,), {
  'DESCRIPTOR' : _KEYTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.KeyType)
  })
_sym_db.RegisterMessage(KeyType)

ObjectType = _reflection.GeneratedProtocolMessageType('ObjectType', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ObjectType)
  })
_sym_db.RegisterMessage(ObjectType)

ArrayType = _reflection.GeneratedProtocolMessageType('ArrayType', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ArrayType)
  })
_sym_db.RegisterMessage(ArrayType)

CustomType = _reflection.GeneratedProtocolMessageType('CustomType', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.CustomType)
  })
_sym_db.RegisterMessage(CustomType)

BitSetProto = _reflection.GeneratedProtocolMessageType('BitSetProto', (_message.Message,), {
  'DESCRIPTOR' : _BITSETPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.BitSetProto)
  })
_sym_db.RegisterMessage(BitSetProto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.format_params import FormatParams  # noqa: F401,E501
from rockset.swagger_client.models.source_dynamo_db import SourceDynamoDb  # noqa: F401,E501
from rockset.swagger_client.models.source_file_upload import SourceFileUpload  # noqa: F401,E501
from rockset.swagger_client.models.source_gcs import SourceGcs  # noqa: F401,E501
from rockset.swagger_client.models.source_kafka import SourceKafka  # noqa: F401,E501
from rockset.swagger_client.models.source_kinesis import SourceKinesis  # noqa: F401,E501
from rockset.swagger_client.models.source_mongo_db import SourceMongoDb  # noqa: F401,E501
from rockset.swagger_client.models.source_redshift import SourceRedshift  # noqa: F401,E501
from rockset.swagger_client.models.source_s3 import SourceS3  # noqa: F401,E501
from rockset.swagger_client.models.status import Status  # noqa: F401,E501


class Source(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'integration_name': 'str',
        's3': 'SourceS3',
        'kinesis': 'SourceKinesis',
        'gcs': 'SourceGcs',
        'redshift': 'SourceRedshift',
        'dynamodb': 'SourceDynamoDb',
        'file_upload': 'SourceFileUpload',
        'kafka': 'SourceKafka',
        'mongodb': 'SourceMongoDb',
        'status': 'Status',
        'format_params': 'FormatParams'
    }

    attribute_map = {
        'integration_name': 'integration_name',
        's3': 's3',
        'kinesis': 'kinesis',
        'gcs': 'gcs',
        'redshift': 'redshift',
        'dynamodb': 'dynamodb',
        'file_upload': 'file_upload',
        'kafka': 'kafka',
        'mongodb': 'mongodb',
        'status': 'status',
        'format_params': 'format_params'
    }

    def __init__(self, integration_name, **kwargs):  # noqa: E501
        """Source - a model defined in Swagger"""  # noqa: E501

        self._integration_name = None
        self._s3 = None
        self._kinesis = None
        self._gcs = None
        self._redshift = None
        self._dynamodb = None
        self._file_upload = None
        self._kafka = None
        self._mongodb = None
        self._status = None
        self._format_params = None
        self.discriminator = None

        self.integration_name = integration_name
        self.s3 = kwargs.pop('s3', None)
        self.kinesis = kwargs.pop('kinesis', None)
        self.gcs = kwargs.pop('gcs', None)
        self.redshift = kwargs.pop('redshift', None)
        self.dynamodb = kwargs.pop('dynamodb', None)
        self.file_upload = kwargs.pop('file_upload', None)
        self.kafka = kwargs.pop('kafka', None)
        self.mongodb = kwargs.pop('mongodb', None)
        self.status = kwargs.pop('status', None)
        self.format_params = kwargs.pop('format_params', None)

    @property
    def integration_name(self):
        """Gets the integration_name of this Source.  # noqa: E501

        name of integration to use  # noqa: E501

        :return: The integration_name of this Source.  # noqa: E501
        :rtype: str
        """
        return self._integration_name

    @integration_name.setter
    def integration_name(self, integration_name):
        """Sets the integration_name of this Source.

        name of integration to use  # noqa: E501

        :param integration_name: The integration_name of this Source.  # noqa: E501
        :type: str
        """

        self._integration_name = integration_name

    @property
    def s3(self):
        """Gets the s3 of this Source.  # noqa: E501

        configuration for ingestion from S3  # noqa: E501

        :return: The s3 of this Source.  # noqa: E501
        :rtype: SourceS3
        """
        return self._s3

    @s3.setter
    def s3(self, s3):
        """Sets the s3 of this Source.

        configuration for ingestion from S3  # noqa: E501

        :param s3: The s3 of this Source.  # noqa: E501
        :type: SourceS3
        """

        self._s3 = s3

    @property
    def kinesis(self):
        """Gets the kinesis of this Source.  # noqa: E501

        configuration for ingestion from kinesis stream  # noqa: E501

        :return: The kinesis of this Source.  # noqa: E501
        :rtype: SourceKinesis
        """
        return self._kinesis

    @kinesis.setter
    def kinesis(self, kinesis):
        """Sets the kinesis of this Source.

        configuration for ingestion from kinesis stream  # noqa: E501

        :param kinesis: The kinesis of this Source.  # noqa: E501
        :type: SourceKinesis
        """

        self._kinesis = kinesis

    @property
    def gcs(self):
        """Gets the gcs of this Source.  # noqa: E501

        configuration for ingestion from GCS  # noqa: E501

        :return: The gcs of this Source.  # noqa: E501
        :rtype: SourceGcs
        """
        return self._gcs

    @gcs.setter
    def gcs(self, gcs):
        """Sets the gcs of this Source.

        configuration for ingestion from GCS  # noqa: E501

        :param gcs: The gcs of this Source.  # noqa: E501
        :type: SourceGcs
        """

        self._gcs = gcs

    @property
    def redshift(self):
        """Gets the redshift of this Source.  # noqa: E501

        configuration for ingestion from Redshift  # noqa: E501

        :return: The redshift of this Source.  # noqa: E501
        :rtype: SourceRedshift
        """
        return self._redshift

    @redshift.setter
    def redshift(self, redshift):
        """Sets the redshift of this Source.

        configuration for ingestion from Redshift  # noqa: E501

        :param redshift: The redshift of this Source.  # noqa: E501
        :type: SourceRedshift
        """

        self._redshift = redshift

    @property
    def dynamodb(self):
        """Gets the dynamodb of this Source.  # noqa: E501

        configuration for ingestion from  a dynamodb table  # noqa: E501

        :return: The dynamodb of this Source.  # noqa: E501
        :rtype: SourceDynamoDb
        """
        return self._dynamodb

    @dynamodb.setter
    def dynamodb(self, dynamodb):
        """Sets the dynamodb of this Source.

        configuration for ingestion from  a dynamodb table  # noqa: E501

        :param dynamodb: The dynamodb of this Source.  # noqa: E501
        :type: SourceDynamoDb
        """

        self._dynamodb = dynamodb

    @property
    def file_upload(self):
        """Gets the file_upload of this Source.  # noqa: E501

        file upload details  # noqa: E501

        :return: The file_upload of this Source.  # noqa: E501
        :rtype: SourceFileUpload
        """
        return self._file_upload

    @file_upload.setter
    def file_upload(self, file_upload):
        """Sets the file_upload of this Source.

        file upload details  # noqa: E501

        :param file_upload: The file_upload of this Source.  # noqa: E501
        :type: SourceFileUpload
        """

        self._file_upload = file_upload

    @property
    def kafka(self):
        """Gets the kafka of this Source.  # noqa: E501

        kafka collection identifier  # noqa: E501

        :return: The kafka of this Source.  # noqa: E501
        :rtype: SourceKafka
        """
        return self._kafka

    @kafka.setter
    def kafka(self, kafka):
        """Sets the kafka of this Source.

        kafka collection identifier  # noqa: E501

        :param kafka: The kafka of this Source.  # noqa: E501
        :type: SourceKafka
        """

        self._kafka = kafka

    @property
    def mongodb(self):
        """Gets the mongodb of this Source.  # noqa: E501

        MongoDB collection details  # noqa: E501

        :return: The mongodb of this Source.  # noqa: E501
        :rtype: SourceMongoDb
        """
        return self._mongodb

    @mongodb.setter
    def mongodb(self, mongodb):
        """Sets the mongodb of this Source.

        MongoDB collection details  # noqa: E501

        :param mongodb: The mongodb of this Source.  # noqa: E501
        :type: SourceMongoDb
        """

        self._mongodb = mongodb

    @property
    def status(self):
        """Gets the status of this Source.  # noqa: E501

        the ingest status of this source  # noqa: E501

        :return: The status of this Source.  # noqa: E501
        :rtype: Status
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Source.

        the ingest status of this source  # noqa: E501

        :param status: The status of this Source.  # noqa: E501
        :type: Status
        """

        self._status = status

    @property
    def format_params(self):
        """Gets the format_params of this Source.  # noqa: E501

        format parameters for data from this source  # noqa: E501

        :return: The format_params of this Source.  # noqa: E501
        :rtype: FormatParams
        """
        return self._format_params

    @format_params.setter
    def format_params(self, format_params):
        """Sets the format_params of this Source.

        format parameters for data from this source  # noqa: E501

        :param format_params: The format_params of this Source.  # noqa: E501
        :type: FormatParams
        """

        self._format_params = format_params

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Source, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Source):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



"""
Usage
-----
Client objects allow you to connect securely to the Rockset service.
All other API calls require a valid Client object.

In order to create a Client object, you will need a valid Rockset
API key. If you have access to the Rockset Console, then you can use
the console to create an API key. If not, please contact the
Rockset team at support@rockset.io

::

    from rockset import Client

    # connect securely to Rockset production API servers
    client = Client(api_server='api.rs2.usw2.rockset.com',
                    api_key='XKQL6YCU0zDUglhWHPMDDmDYyMxDHrASGk5apCnn3A07twh')

You can manage your api_key credentials using the ``rock`` command-line tool.
Run the ``rock configure`` tool to setup one or more api_key credentials and
select the one that you want all ``rock`` commands and the Python Rockset
Client to use. Once setup, you should expect the following to work.

::

    from rockset import Client

    # connect to the active credentials profile
    # you can see see the active profile by running ``rock configure ls``
    rs = Client()

    # connect to credentials profile 'prod' as defined by ``rock configure``
    rs = Client(profile='prod')


Example
-------

Connect to Rockset API server and then subsequently use the client object
to retrieve collections.

::

    from rockset import Client

    # connect securely to Rockset dev API server
    rs = Client(api_server='api-us-west-2.rockset.io',
                api_key='adkjf234rksjfa23waejf2')

    # list all collections in the account that I have access to
    all_collections = rs.Collection.list()

    # create a new collection; returns a collection object
    new_collection = rs.Collection.create('customer_info')

    # get details of an existing collection as a collection object
    users = rs.retrieve('users')

"""
import json
import logging
import os
import platform
import requests
import time
import tempfile
import yaml

from urllib3.exceptions import ReadTimeoutError

import rockset

from rockset.collection import Collection
from rockset.credentials import Credentials
from rockset.cursor import Cursor
from rockset.exception import (
    AuthError, InputError, LimitReached, NotYetImplemented, RequestTimeout,
    ResourceSuspendedError, ServerError, TransientServerError
)
from rockset.field_mapping import FieldMapping
from rockset.clustering_key import ClusteringKey
from rockset.integration import IntegrationClient
from rockset.query import Query
from rockset.source import Source
from rockset.workspace import WorkspaceClient
from rockset.query_lambda import QueryLambdaClient
from rockset.alias import AliasClient

from rockset.swagger_client import (ApiClient, Configuration)
from rockset.swagger_client.rest import ApiException
from rockset.swagger_client.models.query_response import QueryResponse
from rockset.swagger_client.models.query_error import QueryError


class Client(object):
    """Securely connect to Rockset using an API key.

    Optionally, an alternate API server host can also be provided.
    If you have configured credentials using the ``rock configure``
    command, then those credentials will act as fall back values, when
    none of the api_key/api_server parameters are specified.

    Args:
        api_key (str): API key
        api_server (str): API server URL. Will default to https if URL
            does not specify a scheme.
        profile (str): Optionally, you can also specify name of your
            credentials profile setup using ``rock configure``

    Returns:
        Client: Client object

    Raises:
        ValueError: when API key is not specified and
                    could not be fetched from ``rock`` CLI
                    credentials or api_server URL is invalid.
    """

    #: Maximum allowed length of a collection name
    MAX_NAME_LENGTH = 2048

    #: Maximum allowed length of a field name
    MAX_FIELD_NAME_LENGTH = 10 * 1024

    #: Maximum allowed size of a field value
    MAX_FIELD_VALUE_BYTES = 4 * 1024 * 1024

    #: Maximum allowed length of ``_id`` field value
    MAX_ID_VALUE_LENGTH = 10 * 1024

    #: Maximum allowed levels of depth for nested documents
    MAX_NESTED_FIELD_DEPTH = 30

    #: Maximum allowed size of a single document
    MAX_DOCUMENT_SIZE_BYTES = 40 * 1024 * 1024

    # Config directory path
    @classmethod
    def config_dir(cls):
        """Returns name of the directory where Rockset credentials, config,
        and logs are stored.

        Defaults to ``"~/.rockset/"``

        Can be overriddden via ``ROCKSET_CONFIG_HOME`` env variable.
        """
        if 'ROCKSET_CONFIG_HOME' in os.environ:
            homedir = '%s' % os.path.expanduser(
                os.environ['ROCKSET_CONFIG_HOME']
            )
        elif platform.system() == 'Windows':
            homedir = os.path.join(os.path.expanduser('~'), 'AppData', 'Local')
        else:
            homedir = os.path.expanduser('~')

        # if user does not have home dir, use tmpdir
        if not os.path.isdir(homedir):
            homedir = tempfile.gettempdir()

        # config dir is `homedir`/.rockset
        return os.path.join(homedir, '.rockset')

    # Constructor
    def __init__(
        self,
        api_key=None,
        api_server=None,
        profile=None,
        driver=None,
        **kwargs
    ):
        # inititalize api key and server
        self.api_key = api_key
        self.api_server = api_server

        # if both api key and server were not set, default to active profile
        if api_key is None or api_server is None:
            # read credentials from creds file if not supplied
            creds = Credentials()
            active_profile = creds.get(profile=profile)
            if api_key is None:
                self.api_key = active_profile.get('api_key', None)
            if api_server is None:
                self.api_server = active_profile.get('api_server', None)

        # no api_key => no soup for you
        if self.api_key is None:
            raise ValueError("api_key needs to be specified")

        # default to api.rs2.usw2.rockset.com
        if self.api_server is None:
            self.api_server = 'api.rs2.usw2.rockset.com'

        # peel http scheme from api_server setting
        if self.api_server[:7] != 'http://' and self.api_server[:8
                                                               ] != 'https://':
            self.api_server = 'https://' + self.api_server

        configuration = Configuration()
        if 'HTTPS_PROXY' in os.environ:
            configuration.proxy = os.environ['HTTPS_PROXY']
        elif 'HTTP_PROXY' in os.environ:
            configuration.proxy = os.environ['HTTP_PROXY']

        self.user_agent = 'python'
        if driver is not None:
            self.user_agent += ':'
            self.user_agent += driver

        # init swagger client
        self.api_client = ApiClient(
            api_key=self.api_key,
            api_server=self.api_server,
            version=rockset.version(),
            user_agent=self.user_agent,
            configuration=configuration
        )

        # create instances of helper classes
        self.Collection = CollectionClient(client=self)
        self.Source = SourceClient(client=self)
        self.FieldMapping = FieldMappingClient(client=self)
        self.ClusteringKey = ClusteringKeyClient(client=self)
        self.Integration = IntegrationClient(client=self)
        self.Workspace = WorkspaceClient(client=self)
        self.QueryLambda = QueryLambdaClient(client=self)
        self.Alias = AliasClient(client=self)

        # init config dir
        self.config_dir = Client.config_dir()

        # init logging
        self.logger = logging.getLogger(__name__)
        self.logger.addHandler(logging.NullHandler())
        return

    def _get_error_model(self, e):
        try:
            model = json.loads(e.body)
            return (model.get('message', None), model.get('type', None))
        except:
            pass
        return (None, None)

    def _process_exception(self, message, errtype, status_code, e):
        if status_code == 401:
            raise AuthError(code=status_code, message=message) from None
        elif status_code == 403 or status_code == 413 or status_code == 429:
            raise LimitReached(code=status_code, message=message, type=type) \
                from None
        elif status_code == 400:
            raise InputError(
                code=status_code, message=message, type=errtype
            ) from None
        elif status_code == 501:
            raise NotYetImplemented(
                code=status_code, message=message, type=errtype
            ) from None
        elif status_code == 503 or status_code == 504:
            raise TransientServerError(
                code=status_code, message=message, type=errtype
            ) from None
        elif status_code == 502:
            message = "502 error connecting to {}".format(self.api_server)
            elapsed = int(time.time() - start_time)
            raise RequestTimeout(message=message, timeout=elapsed) from None
        elif status_code > 400 and status_code < 500:
            raise InputError(
                code=status_code, message=message, type=errtype
            ) from None
        elif status_code >= 500 and status_code < 530:
            raise ServerError(
                code=status_code, message=message, type=errtype
            ) from None
        elif status_code == 530:
            raise ResourceSuspendedError(
                code=status_code, message=message, type=errtype
            ) from None
        elif e is not None:
            raise e
        else:
            raise Exception(message)

    def call_api(self, resource, method, *args, **kwargs):
        try:
            start_time = time.time()
            result = self.api_client.call_api(resource, method, *args, **kwargs)

            if isinstance(result, QueryResponse):
                # Check and throw if a query error exists.
                if result.query_errors is not None and len(
                    result.query_errors
                ) > 0:
                    # Right now, the server only sends one error at most, so only consider that.
                    query_error = result.query_errors[0]
                    self._process_exception(
                        query_error.message, query_error.type,
                        query_error.status_code, None
                    )

        except ApiException as e:
            (message, errtype) = self._get_error_model(e)
            self._process_exception(message, errtype, e.status, e)
        except ReadTimeoutError as e:
            raise RequestTimeout(
                message=str(e), timeout=kwargs.get('_request_timeout')
            )
        return result

    def list(self, **kwargs):
        return Collection.list(client=self)

    def retrieve(self, name, workspace="commons"):
        return Collection.retrieve(name=name, workspace=workspace, client=self)

    def query(self, q, collection=None, **kwargs):
        # Collection is ignored.
        return self.sql(q, **kwargs)

    def sql(self, q, **kwargs):
        """Execute a query against Rockset.

        This method prepares the given query object and binds it to
        a Cursor_ object, and returns that Cursor object. The request is not
        actually dispatched to the backend until the results are fetched
        from the cursor.

        Input query needs to be supplied as a Query_ object.

        Cursor objects are iterable, and you can iterate through a cursor to
        fetch the results. The entire result data set can also be retrieved
        from the cursor object using a single ``results()`` call.

        When you iterate through the cursor in a loop, the cursor objects
        implement automatic pagination behind the scenes. If the query
        returns a large number of results, with automatic pagination,
        only a portion of the results are buffered into the cursor at a
        time. As the cursor iterator reaches the end of the current batch,
        it will automatically issue a new query to fetch the next batch
        and seamlessly resume. Cursor's default iterator uses batch size
        of 10,000, and you can create an iterator of a different batch size
        using the iter() method in the cursor object.

        Example::

            ...
            rs = Client()
            cursor = rs.sql(q)

            # fetch all results in 1 go
            all_results = cursor.results()

            # iterate through all results;
            # automatic pagination with default iterator batch size of 100
            # if len(all_results) == 21,442, then as part of looping
            # through the results, three distinct queries would be
            # issued with (limit, skip) of (10000, 0), (10000, 10000),
            # (10000, 20000)
            for result in cursor:
                print(result)

            # iterate through all results;
            # automatic pagination with iterator batch size of 20,000
            # if len(all_results) == 21,442, then as part of looping
            # through the results, two distinct queries would have
            # been issued with (limit, skip) of (20000, 0), (20000, 20000).
            for result in cursor.iter(20000):
                print(result)
            ...

        Args:
            q (Query): Input Query object
            timeout (int): Client side timeout. When specified, RequestTimeout_ \
            exception will be thrown upon timeout expiration. By default, \
            the client will wait indefinitely until it receives results or \
            an error from the server.

        Returns:
            Cursor: returns a cursor that can fetch query results with or
            without automatic pagination
        """

        if not isinstance(q, Query):
            raise NotImplementedError(
                'query of type {} not supported'.format(type(q))
            )
        return Cursor(
            q=q,
            client=self,
            generate_warnings=kwargs.get('generate_warnings', False),
            timeout=kwargs.get('timeout')
        )


class CollectionClient(object):
    def __init__(self, client):
        self.client = client

    def create(self, name, workspace="commons", description=None, **kwargs):
        sources = [dict(s) for s in kwargs.pop('sources', [])]
        field_mappings = [dict(m) for m in kwargs.pop('field_mappings', [])]
        clustering_key = [dict(m) for m in kwargs.pop('clustering_key', [])]
        return Collection.create(
            name=name,
            workspace=workspace,
            description=description,
            sources=sources,
            field_mappings=field_mappings,
            clustering_key=clustering_key,
            client=self.client,
            **kwargs
        )

    def list(self, *args, **kwargs):
        kwargs['client'] = self.client
        return Collection.list(*args, **kwargs)

    def retrieve(self, name, workspace="commons"):
        return Collection.retrieve(
            name=name, workspace=workspace, client=self.client
        )

    def add_docs(self, name, docs, **kwargs):
        c = Collection(name=name, client=self.client, **kwargs)
        return c.add_docs(docs, **kwargs)

    def patch_docs(self, name, docpatches, **kwargs):
        c = Collection(name=name, client=self.client, **kwargs)
        return c.patch_docs(docpatches, **kwargs)

    def remove_docs(self, name, docs, **kwargs):
        c = Collection(name=name, client=self.client, **kwargs)
        return c.remove_docs(docs, **kwargs)


class SourceClient(object):
    def __init__(self, client):
        self.client = client

    def s3(self, *args, **kwargs):
        return Source.s3(*args, **kwargs)

    def mongo(self, *args, **kwargs):
        return Source.mongo(*args, **kwargs)

    def dynamo(self, *args, **kwargs):
        return Source.dynamo(*args, **kwargs)

    def kinesis(self, *args, **kwargs):
        return Source.kinesis(*args, **kwargs)

    def gcs(self, *args, **kwargs):
        return Source.gcs(*args, **kwargs)

    def redshift(self, *args, **kwargs):
        return Source.redshift(*args, **kwargs)

    def kafka(self, *args, **kwargs):
        return Source.kafka(*args, **kwargs)

    def csv_params(self, *args, **kwargs):
        return Source.csv_params(*args, **kwargs)

    def xml_params(self, *args, **kwargs):
        return Source.xml_params(*args, **kwargs)


class FieldMappingClient(object):
    def __init__(self, client):
        self.client = client

    def mapping(self, *args, **kwargs):
        return FieldMapping.mapping(*args, **kwargs)

    def input_field(self, *args, **kwargs):
        return FieldMapping.input_field(*args, **kwargs)

    def output_field(self, *args, **kwargs):
        return FieldMapping.output_field(*args, **kwargs)


class ClusteringKeyClient(object):
    def __init__(self, client):
        self.client = client

    def clusteringField(self, *args, **kwargs):
        return ClusteringKey.clusteringField(*args, **kwargs)


__all__ = [
    'Client',
]



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class VirtualInstance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'state': 'str',
        'current_type': 'str',
        'desired_type': 'str',
        'current_size': 'str',
        'desired_size': 'str',
        'last_updated': 'str',
        'estimated_switch_duration_minutes': 'int',
        'monitoring_enabled': 'bool',
        'default_pod_count': 'int',
        'scaled_pod_count': 'int',
        'id': 'str'
    }

    attribute_map = {
        'state': 'state',
        'current_type': 'current_type',
        'desired_type': 'desired_type',
        'current_size': 'current_size',
        'desired_size': 'desired_size',
        'last_updated': 'last_updated',
        'estimated_switch_duration_minutes': 'estimated_switch_duration_minutes',
        'monitoring_enabled': 'monitoring_enabled',
        'default_pod_count': 'default_pod_count',
        'scaled_pod_count': 'scaled_pod_count',
        'id': 'id'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """VirtualInstance - a model defined in Swagger"""  # noqa: E501

        self._state = None
        self._current_type = None
        self._desired_type = None
        self._current_size = None
        self._desired_size = None
        self._last_updated = None
        self._estimated_switch_duration_minutes = None
        self._monitoring_enabled = None
        self._default_pod_count = None
        self._scaled_pod_count = None
        self._id = None
        self.discriminator = None

        self.state = kwargs.pop('state', None)
        self.current_type = kwargs.pop('current_type', None)
        self.desired_type = kwargs.pop('desired_type', None)
        self.current_size = kwargs.pop('current_size', None)
        self.desired_size = kwargs.pop('desired_size', None)
        self.last_updated = kwargs.pop('last_updated', None)
        self.estimated_switch_duration_minutes = kwargs.pop('estimated_switch_duration_minutes', None)
        self.monitoring_enabled = kwargs.pop('monitoring_enabled', None)
        self.default_pod_count = kwargs.pop('default_pod_count', None)
        self.scaled_pod_count = kwargs.pop('scaled_pod_count', None)
        self.id = kwargs.pop('id', None)

    @property
    def state(self):
        """Gets the state of this VirtualInstance.  # noqa: E501

        virtual instance state  # noqa: E501

        :return: The state of this VirtualInstance.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this VirtualInstance.

        virtual instance state  # noqa: E501

        :param state: The state of this VirtualInstance.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def current_type(self):
        """Gets the current_type of this VirtualInstance.  # noqa: E501


        :return: The current_type of this VirtualInstance.  # noqa: E501
        :rtype: str
        """
        return self._current_type

    @current_type.setter
    def current_type(self, current_type):
        """Sets the current_type of this VirtualInstance.


        :param current_type: The current_type of this VirtualInstance.  # noqa: E501
        :type: str
        """

        self._current_type = current_type

    @property
    def desired_type(self):
        """Gets the desired_type of this VirtualInstance.  # noqa: E501


        :return: The desired_type of this VirtualInstance.  # noqa: E501
        :rtype: str
        """
        return self._desired_type

    @desired_type.setter
    def desired_type(self, desired_type):
        """Sets the desired_type of this VirtualInstance.


        :param desired_type: The desired_type of this VirtualInstance.  # noqa: E501
        :type: str
        """

        self._desired_type = desired_type

    @property
    def current_size(self):
        """Gets the current_size of this VirtualInstance.  # noqa: E501

        virtual instance current size  # noqa: E501

        :return: The current_size of this VirtualInstance.  # noqa: E501
        :rtype: str
        """
        return self._current_size

    @current_size.setter
    def current_size(self, current_size):
        """Sets the current_size of this VirtualInstance.

        virtual instance current size  # noqa: E501

        :param current_size: The current_size of this VirtualInstance.  # noqa: E501
        :type: str
        """

        self._current_size = current_size

    @property
    def desired_size(self):
        """Gets the desired_size of this VirtualInstance.  # noqa: E501

        virtual instance desired size  # noqa: E501

        :return: The desired_size of this VirtualInstance.  # noqa: E501
        :rtype: str
        """
        return self._desired_size

    @desired_size.setter
    def desired_size(self, desired_size):
        """Sets the desired_size of this VirtualInstance.

        virtual instance desired size  # noqa: E501

        :param desired_size: The desired_size of this VirtualInstance.  # noqa: E501
        :type: str
        """

        self._desired_size = desired_size

    @property
    def last_updated(self):
        """Gets the last_updated of this VirtualInstance.  # noqa: E501

        ISO-8601 date of when virtual instance size was last updated  # noqa: E501

        :return: The last_updated of this VirtualInstance.  # noqa: E501
        :rtype: str
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this VirtualInstance.

        ISO-8601 date of when virtual instance size was last updated  # noqa: E501

        :param last_updated: The last_updated of this VirtualInstance.  # noqa: E501
        :type: str
        """

        self._last_updated = last_updated

    @property
    def estimated_switch_duration_minutes(self):
        """Gets the estimated_switch_duration_minutes of this VirtualInstance.  # noqa: E501

        estimated duration in minutes of last virtual instance size update  # noqa: E501

        :return: The estimated_switch_duration_minutes of this VirtualInstance.  # noqa: E501
        :rtype: int
        """
        return self._estimated_switch_duration_minutes

    @estimated_switch_duration_minutes.setter
    def estimated_switch_duration_minutes(self, estimated_switch_duration_minutes):
        """Sets the estimated_switch_duration_minutes of this VirtualInstance.

        estimated duration in minutes of last virtual instance size update  # noqa: E501

        :param estimated_switch_duration_minutes: The estimated_switch_duration_minutes of this VirtualInstance.  # noqa: E501
        :type: int
        """

        self._estimated_switch_duration_minutes = estimated_switch_duration_minutes

    @property
    def monitoring_enabled(self):
        """Gets the monitoring_enabled of this VirtualInstance.  # noqa: E501


        :return: The monitoring_enabled of this VirtualInstance.  # noqa: E501
        :rtype: bool
        """
        return self._monitoring_enabled

    @monitoring_enabled.setter
    def monitoring_enabled(self, monitoring_enabled):
        """Sets the monitoring_enabled of this VirtualInstance.


        :param monitoring_enabled: The monitoring_enabled of this VirtualInstance.  # noqa: E501
        :type: bool
        """

        self._monitoring_enabled = monitoring_enabled

    @property
    def default_pod_count(self):
        """Gets the default_pod_count of this VirtualInstance.  # noqa: E501


        :return: The default_pod_count of this VirtualInstance.  # noqa: E501
        :rtype: int
        """
        return self._default_pod_count

    @default_pod_count.setter
    def default_pod_count(self, default_pod_count):
        """Sets the default_pod_count of this VirtualInstance.


        :param default_pod_count: The default_pod_count of this VirtualInstance.  # noqa: E501
        :type: int
        """

        self._default_pod_count = default_pod_count

    @property
    def scaled_pod_count(self):
        """Gets the scaled_pod_count of this VirtualInstance.  # noqa: E501


        :return: The scaled_pod_count of this VirtualInstance.  # noqa: E501
        :rtype: int
        """
        return self._scaled_pod_count

    @scaled_pod_count.setter
    def scaled_pod_count(self, scaled_pod_count):
        """Sets the scaled_pod_count of this VirtualInstance.


        :param scaled_pod_count: The scaled_pod_count of this VirtualInstance.  # noqa: E501
        :type: int
        """

        self._scaled_pod_count = scaled_pod_count

    @property
    def id(self):
        """Gets the id of this VirtualInstance.  # noqa: E501

        unique identifier for virtual instance  # noqa: E501

        :return: The id of this VirtualInstance.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VirtualInstance.

        unique identifier for virtual instance  # noqa: E501

        :param id: The id of this VirtualInstance.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VirtualInstance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VirtualInstance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)
